pub struct HxReswap(pub Swap);Expand description
allows you to specify how the response will be swapped. See hx-swap for possible values
Tuple Fields
0: SwapTrait Implementations
Sourceimpl Header for HxReswap
impl Header for HxReswap
Sourcefn encode<E: Extend<HeaderValue>>(&self, values: &mut E)
fn encode<E: Extend<HeaderValue>>(&self, values: &mut E)
NOTE: Panics if the value cannot be converted to a header value.
Sourcefn name() -> &'static HeaderName
fn name() -> &'static HeaderName
The name of this header.
impl Copy for HxReswap
impl Eq for HxReswap
impl StructuralPartialEq for HxReswap